fn value_for_place<'a, 'tcx>(
forward: &'a ForwardVisitResult<'tcx>,
place: &PlaceKey,
) -> Option<&'a AbstractValue<'tcx>>Expand description
Return the abstract value assigned to a place when it is tracked by local.
fn value_for_place<'a, 'tcx>(
forward: &'a ForwardVisitResult<'tcx>,
place: &PlaceKey,
) -> Option<&'a AbstractValue<'tcx>>Return the abstract value assigned to a place when it is tracked by local.